@@ -18,15 +18,9 @@
 
 #ifndef IMAGEPREVIEW_H
 #define IMAGEPREVIEW_H
-#include "config-kpa-kface.h"
 #include "DB/ImageInfo.h"
 #include "ImageManager/ImageClientInterface.h"
 
-#ifdef HAVE_KFACE
-#include "FaceManagement/Detector.h"
-#include "FaceManagement/Recognizer.h"
-#endif
-
 #include <QLabel>
 #include <QTimer>
 
@@ -54,27 +48,20 @@ public:
     void createTaggedArea(QString category, QString tag, QRect geometry, bool showArea);
     QSize getActualImageSize();
     void acceptProposedTag(QPair<QString, QString> tagData, ResizableFrame *area);
-#ifdef HAVE_KFACE
-    void trainRecognitionDatabase(QRect geometry, QPair<QString, QString> tagData);
-    void recognizeArea(ResizableFrame *area);
-#endif
     QPixmap grabAreaImage(QRect area);
 
 public slots:
     void setAreaCreationEnabled(bool state);
-#ifdef HAVE_KFACE
-    void detectFaces();
-#endif
 
 signals:
     void areaCreated(ResizableFrame *area);
     void proposedTagSelected(QString category, QString tag);
 
 protected:
-    virtual void resizeEvent( QResizeEvent* );
-    virtual void mousePressEvent(QMouseEvent *event);
-    virtual void mouseMoveEvent(QMouseEvent *event);
-    virtual void mouseReleaseEvent(QMouseEvent *event);
+    virtual void resizeEvent( QResizeEvent* ) override;
+    virtual void mousePressEvent(QMouseEvent *event) override;
+    virtual void mouseMoveEvent(QMouseEvent *event) override;
+    virtual void mouseReleaseEvent(QMouseEvent *event) override;
     void reload();
     void setCurrentImage(const QImage &image);
     QImage rotateAndScale( QImage, int width, int height, int angle ) const;
@@ -139,10 +126,6 @@ private:
     QRect rotateArea(QRect originalAreaGeometry, int angle);
     bool m_areaCreationEnabled;
     QMap<QString, QPair<int, QSize>> m_imageSizes;
-#ifdef HAVE_KFACE
-    FaceManagement::Recognizer *m_recognizer;
-    FaceManagement::Detector *m_detector;
-#endif
     QImage m_fullSizeImage;
     void fetchFullSizeImage();
     bool fuzzyAreaExists(QList<QRect> &existingAreas, QRect area);
