@@ -23,10 +23,6 @@
 #include "Settings/SettingsData.h"
 #include "DB/CategoryPtr.h"
 #include <QList>
-#include <config-kpa-kface.h>
-#ifdef HAVE_KFACE
-#include "FaceManagement/Recognizer.h"
-#endif
 
 class QTreeWidgetItem;
 class CategoryItem;
@@ -130,9 +126,6 @@ private: // Variables
     QToolButton* m_showSelectedOnly;
     QString m_baseTitle;
     bool m_positionable;
-#ifdef HAVE_KFACE
-    FaceManagement::Recognizer* m_recognizer;
-#endif
 };
 
 }
