@@ -18,10 +18,8 @@
 
 #include "ImageInfo.h"
 
-#include <QDebug>
-#include <QFile>
-#include <QFileInfo>
-#include <QStringList>
+#include "FileInfo.h"
+#include "Logging.h"
 
 #include <DB/CategoryCollection.h>
 #include <DB/ImageDB.h>
@@ -29,9 +27,12 @@
 #include <Exif/DatabaseElement.h>
 #include <Exif/Database.h>
 #include <Settings/SettingsData.h>
-#include <Utilities/Set.h>
+#include <Utilities/StringSet.h>
 #include <Utilities/Util.h>
-#include "FileInfo.h"
+
+#include <QFile>
+#include <QFileInfo>
+#include <QStringList>
 
 using namespace DB;
 
@@ -127,7 +128,14 @@ bool ImageInfo::hasCategoryInfo( const QString& key, const QString& value ) cons
 
 bool DB::ImageInfo::hasCategoryInfo( const QString& key, const StringSet& values ) const
 {
-    return Utilities::overlap( m_categoryInfomation[key], values );
+    // OpenSuse leap 42.1 still ships with Qt 5.5
+    // TODO: remove this version check once we don't care about Qt 5.6 anymore...
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
+    return values.intersects( m_categoryInfomation[key] );
+#else
+    StringSet tmp = values;
+    return ! tmp.intersect( m_categoryInfomation[key] ).isEmpty();
+#endif
 }
 
 
@@ -647,7 +655,7 @@ void ImageInfo::merge(const ImageInfo &other)
 
         DB::ImageDB::instance()->unstack(stackImages);
         if (!DB::ImageDB::instance()->stack(stackImages))
-            qWarning("Could not merge stacks!");
+            qCWarning(DBLog, "Could not merge stacks!");
     }
 }
 
