@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2018 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -15,12 +15,12 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
+
 #include "Exif/TreeView.h"
-#include "Utilities/Set.h"
+#include "Utilities/StringSet.h"
 #include <qmap.h>
 #include <qstringlist.h>
 #include "Exif/Info.h"
-#include <QDebug>
 
 using Utilities::StringSet;
 
@@ -98,5 +98,4 @@ void Exif::TreeView::reload()
         item->setExpanded( true );
 }
 
-#include "TreeView.moc"
 // vi:expandtab:tabstop=4 shiftwidth=4:
