@@ -18,23 +18,21 @@
 #ifndef HTMLGENERATOR_GENERATOR_H
 #define HTMLGENERATOR_GENERATOR_H
 
+#include <DB/CategoryPtr.h>
+#include <ImageManager/ImageClientInterface.h>
+#include <Utilities/UniqFilenameMapper.h>
+#include "Setup.h"
+
 #include <QEventLoop>
 #include <QPointer>
 #include <QProgressDialog>
 #include <QString>
 #include <QTemporaryDir>
 
-#include <DB/CategoryPtr.h>
-#include <ImageManager/ImageClientInterface.h>
-#include <Utilities/Set.h>
-#include <Utilities/UniqFilenameMapper.h>
-#include "Setup.h"
-
 namespace DB { class Id; }
 
 namespace HTMLGenerator
 {
-using Utilities::StringSet;
 
 class Generator :public QProgressDialog, private ImageManager::ImageClientInterface
 {
