@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2016 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2018 Jesper K. Pedersen <blackie@kde.org>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public
@@ -17,10 +17,10 @@
 */
 
 #include "HTMLDialog.h"
+#include "Logging.h"
 
 #include <QCheckBox>
 #include <QComboBox>
-#include <QDebug>
 #include <QDialogButtonBox>
 #include <QFileDialog>
 #include <QGroupBox>
@@ -56,12 +56,6 @@
 
 using namespace HTMLGenerator;
 
-#ifdef DEBUG_HTMLGENERATOR
-#define Debug qDebug
-#else
-#define Debug if(0) qDebug
-#endif
-
 HTMLDialog::HTMLDialog( QWidget* parent )
    : KPageDialog(parent)
    , m_list()
@@ -527,13 +521,13 @@ void HTMLDialog::populateThemesCombo()
     int i = 0;
     int theme = 0;
     int defaultthemes = 0;
-    Debug() << "Theme directories:"<<dirs;
+    qCDebug(HTMLGeneratorLog) << "Theme directories:"<<dirs;
     for(QStringList::Iterator it = dirs.begin(); it != dirs.end(); ++it) {
         QDir dir(*it);
-        Debug() << "Searching themes in:"<<dir;
+        qCDebug(HTMLGeneratorLog) << "Searching themes in:"<<dir;
         QStringList themes = dir.entryList( QDir::Dirs | QDir::Readable );
         for(QStringList::Iterator it = themes.begin(); it != themes.end(); ++it) {
-            Debug() << " *" << *it;
+            qCDebug(HTMLGeneratorLog) << " *" << *it;
             if(*it == QString::fromLatin1(".") || *it == QString::fromLatin1("..")) continue;
             QString themePath = QString::fromLatin1("%1/%2/").arg(dir.path()).arg(*it);
 
@@ -614,7 +608,7 @@ int HTMLDialog::exec(const DB::FileNameList& list)
 {
     if (list.empty())
     {
-        qWarning() << "HTMLDialog called without images for export";
+        qCWarning(HTMLGeneratorLog) << "HTMLDialog called without images for export";
         return false;
     }
     m_list = list;
@@ -654,5 +648,4 @@ Setup HTMLGenerator::HTMLDialog::setup() const
     return setup;
 }
 
-#include "HTMLDialog.moc"
 // vi:expandtab:tabstop=4 shiftwidth=4:
