@@ -18,19 +18,15 @@
 */
 
 #include "VideoLengthExtractor.h"
-#include <Utilities/Process.h>
-#include <QDir>
+#include "Logging.h"
+
 #include <MainWindow/FeatureDialog.h>
-#include <QDebug>
+#include <Utilities/Process.h>
+
+#include <QDir>
 
 #define STR(x) QString::fromUtf8(x)
 
-#if 0
-#  define Debug qDebug
-#else
-#  define Debug if(0) qDebug
-#endif
-
 ImageManager::VideoLengthExtractor::VideoLengthExtractor(QObject *parent) :
     QObject(parent), m_process(nullptr)
 {
@@ -64,12 +60,12 @@ void ImageManager::VideoLengthExtractor::extract(const DB::FileName &fileName)
         m_process->start(MainWindow::FeatureDialog::mplayerBinary(), arguments);
     } else {
         QStringList arguments;
-        arguments << STR("-v") << STR("error") << STR("-select_streams") << STR("v:0")
-                  << STR("-show_entries") << STR("stream=duration")
+        // Just look at the length of the container. Some videos have streams without duration entry
+        arguments << STR("-v") << STR("0") << STR("-show_entries") << STR("format=duration")
                   << STR("-of") << STR("default=noprint_wrappers=1:nokey=1")
                   <<  fileName.absolute();
 
-        //qDebug( "%s %s", qPrintable(MainWindow::FeatureDialog::ffprobeBinary()), qPrintable(arguments.join(QString::fromLatin1(" "))));
+        qCDebug(ImageManagerLog, "%s %s", qPrintable(MainWindow::FeatureDialog::ffprobeBinary()), qPrintable(arguments.join(QString::fromLatin1(" "))));
         m_process->start(MainWindow::FeatureDialog::ffprobeBinary(), arguments);
     }
 }
@@ -77,7 +73,7 @@ void ImageManager::VideoLengthExtractor::extract(const DB::FileName &fileName)
 void ImageManager::VideoLengthExtractor::processEnded()
 {
     if ( !m_process->stderr().isEmpty() )
-        Debug() << m_process->stderr();
+        qCDebug(ImageManagerLog) << m_process->stderr();
 
     QString lenStr;
     if (MainWindow::FeatureDialog::ffmpegBinary().isEmpty())
@@ -85,7 +81,7 @@ void ImageManager::VideoLengthExtractor::processEnded()
         QStringList list = m_process->stdout().split(QChar::fromLatin1('\n'));
         list = list.filter(STR("ID_LENGTH="));
         if ( list.count() == 0 ) {
-            qWarning() << "Unable to find ID_LENGTH in output from MPlayer for file " << m_fileName.absolute() << "\n"
+            qCWarning(ImageManagerLog) << "Unable to find ID_LENGTH in output from MPlayer for file " << m_fileName.absolute() << "\n"
                        << "Output was:\n"
                        << m_process->stdout();
             emit unableToDetermineLength();
@@ -96,7 +92,7 @@ void ImageManager::VideoLengthExtractor::processEnded()
         const QRegExp regexp(STR("ID_LENGTH=([0-9.]+)"));
         if (!regexp.exactMatch(match))
         {
-            qWarning() << STR("Unable to match regexp for string: %1 (for file %2)").arg(match).arg(m_fileName.absolute());
+            qCWarning(ImageManagerLog) << STR("Unable to match regexp for string: %1 (for file %2)").arg(match).arg(m_fileName.absolute());
             emit unableToDetermineLength();
             return;
         }
@@ -104,11 +100,9 @@ void ImageManager::VideoLengthExtractor::processEnded()
         lenStr = regexp.cap(1);
     } else {
         QStringList list = m_process->stdout().split(QChar::fromLatin1('\n'));
-        // one line-break -> 2 parts
-        // some videos with subtitles or other additional streams might have more than one line
-        // in these cases, we just take the first one as both lengths should be the same anyways
-        if ( list.count() < 2 ) {
-            qWarning() << "Unable to parse video length from ffprobe output!"
+        // ffprobe -v 0 just prints one line, except if panicking
+        if ( list.count() < 1 ) {
+            qCWarning(ImageManagerLog) << "Unable to parse video length from ffprobe output!"
                        << "Output was:\n"
                        << m_process->stdout();
             emit unableToDetermineLength();
@@ -120,13 +114,13 @@ void ImageManager::VideoLengthExtractor::processEnded()
     bool ok = false;
     const double length = lenStr.toDouble(&ok);
     if ( !ok ) {
-        qWarning() << STR("Unable to convert string \"%1\"to double (for file %2)").arg(lenStr).arg(m_fileName.absolute());
+        qCWarning(ImageManagerLog) << STR("Unable to convert string \"%1\"to double (for file %2)").arg(lenStr).arg(m_fileName.absolute());
         emit unableToDetermineLength();
         return;
     }
 
     if ( length == 0 ) {
-        qWarning() << "video length returned was 0 for file " << m_fileName.absolute();
+        qCWarning(ImageManagerLog) << "video length returned was 0 for file " << m_fileName.absolute();
         emit unableToDetermineLength();
         return;
     }
