@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2018 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -15,14 +15,16 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
+
 #include <config-kpa-kipi.h>
-#include <config-kpa-kface.h>
 #include <config-kpa-kgeomap.h>
 #include "FeatureDialog.h"
 
+#include <QDialogButtonBox>
 #include <QLayout>
 #include <QList>
 #include <QProcess>
+#include <QPushButton>
 #include <QStandardPaths>
 #include <QTextBrowser>
 #include <QVBoxLayout>
@@ -78,11 +80,6 @@ FeatureDialog::FeatureDialog( QWidget* parent )
                   "needs an Sqlite database. "
                   "In addition the qt package for sqlite (e.g.qt-sql-sqlite) must be installed.</p>");
 
-    text += i18n("<h1><a name=\"kface\">Face detection and recognition support</a></h1>"
-                 "<p>If KPhotoAlbum has been built with support for libkface, "
-                 "face detection and recognition features are enabled in the annotation dialog."
-                 "</p>");
-
     text += i18n("<h1><a name=\"geomap\">Map view for geotagged images</a></h1>"
                  "<p>If KPhotoAlbum has been built with support for libkgeomap, "
                  "KPhotoAlbum can show images with GPS information on a map."
@@ -119,6 +116,12 @@ FeatureDialog::FeatureDialog( QWidget* parent )
     QVBoxLayout* layout = new QVBoxLayout;
     layout->addWidget(browser);
     this->setLayout(layout);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok);
+    buttonBox->button(QDialogButtonBox::Ok)->setShortcut(Qt::CTRL | Qt::Key_Return);
+    layout->addWidget(buttonBox);
+
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
 }
 
 QSize FeatureDialog::sizeHint() const
@@ -140,15 +143,6 @@ bool MainWindow::FeatureDialog::hasEXIV2DBSupport()
     return Exif::Database::isAvailable();
 }
 
-bool MainWindow::FeatureDialog::hasKfaceSupport()
-{
-#ifdef HAVE_KFACE
-    return true;
-#else
-    return false;
-#endif
-}
-
 bool MainWindow::FeatureDialog::hasGeoMapSupport()
 {
 #ifdef HAVE_KGEOMAP
@@ -202,7 +196,7 @@ bool FeatureDialog::hasVideoProber()
 bool MainWindow::FeatureDialog::hasAllFeaturesAvailable()
 {
     // Only answer those that are compile time tests, otherwise we will pay a penalty each time we start up.
-    return hasKIPISupport() && hasEXIV2DBSupport() && hasKfaceSupport() && hasGeoMapSupport() && hasVideoThumbnailer() && hasVideoProber();
+    return hasKIPISupport() && hasEXIV2DBSupport() && hasGeoMapSupport() && hasVideoThumbnailer() && hasVideoProber();
 }
 
 struct Data
@@ -220,7 +214,6 @@ QString MainWindow::FeatureDialog::featureString()
     QList<Data> features;
     features << Data( i18n("Plug-ins available"), QString::fromLatin1("#kipi"),  hasKIPISupport() );
     features << Data( i18n( "Sqlite database support (used for EXIF searches)" ), QString::fromLatin1("#database"), hasEXIV2DBSupport() );
-    features << Data( i18n( "Face detection and recognition support" ), QString::fromLatin1("#kface"),  hasKfaceSupport() );
     features << Data( i18n( "Map view for geotagged images." ), QString::fromLatin1("#geomap"),  hasGeoMapSupport() );
     features << Data( i18n( "Video support" ), QString::fromLatin1("#video"),  !supportedVideoMimeTypes().isEmpty() );
 
@@ -250,5 +243,4 @@ QStringList MainWindow::FeatureDialog::supportedVideoMimeTypes()
     return Phonon::BackendCapabilities::availableMimeTypes();
 }
 
-#include "FeatureDialog.moc"
 // vi:expandtab:tabstop=4 shiftwidth=4:
