@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2018 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -18,7 +18,6 @@
 
 #include "SplashScreen.h"
 
-#include <QDebug>
 #include <QPainter>
 #include <QRegExp>
 
@@ -72,5 +71,4 @@ void MainWindow::SplashScreen::drawContents( QPainter * painter )
     painter->restore();
 }
 
-#include "SplashScreen.moc"
 // vi:expandtab:tabstop=4 shiftwidth=4:
