@@ -22,16 +22,17 @@
 #include <config-kpa-kipi.h>
 #include "Plugins/ImageCollection.h"
 #include "DB/ImageSearchInfo.h"
-#include <kdemacros.h>
 namespace Plugins
 {
 
-class KDE_EXPORT CategoryImageCollection :public Plugins::ImageCollection {
+class CategoryImageCollection :public Plugins::ImageCollection {
 
 public:
     CategoryImageCollection( const DB::ImageSearchInfo& context, const QString& category, const QString& value );
-    virtual QString name();
-    virtual KUrl::List images();
+
+    virtual QString name() override;
+    virtual QList<QUrl> images() override;
+
 private:
     DB::ImageSearchInfo m_context;
     const QString m_category;
