@@ -46,7 +46,7 @@ public:
 
 protected:
     // just fake a selectionChanged event when first shown to make export plugin happy:
-    virtual void showEvent(QShowEvent *event);
+    virtual void showEvent(QShowEvent *event) override;
 
 private:
     Interface *m_interface;
