@@ -53,7 +53,8 @@ private slots:
     void changeCategory(int index);
     void resetCategory();
     void editDate(int row, int);
-    void parseDate(QString date);
+    QDate parseDate(QString date);
+    void checkDateInput(QString date);
     void checkDate();
     void setDate(const QDate& date);
     void removeDate();
@@ -79,6 +80,7 @@ private: // Variables
     QString m_noDateString;
     QMap<QString, QMap<QString, QDate>> m_changedData;
     QLabel* m_birthdayOfLabel;
+    QStringList m_dateFormats;
 };
 
 }
