@@ -24,7 +24,6 @@
 
 // Local includes
 #include "DB/Category.h"
-#include "config-kpa-kface.h"
 
 namespace DB {
 
@@ -63,11 +62,6 @@ public:
     QString originalName() const;
     void markAsNewCategory();
 
-#ifdef HAVE_KFACE
-signals:
-    void newCategoryNameSaved(QString oldName, QString newName);
-#endif
-
 protected:
     void renameCategory(DB::MemberMap* memberMap);
 
