@@ -57,10 +57,9 @@ void ThumbnailView::MouseTrackingInteraction::handleCursorOverNewIcon()
 {
     static DB::FileName lastFileNameUnderCursor;
     const DB::FileName fileName = widget()->mediaIdUnderCursor();
-    Q_ASSERT( !fileName.isNull());
 
     if ( fileName != lastFileNameUnderCursor ) {
-        if ( !lastFileNameUnderCursor.isNull() )
+        if ( !fileName.isNull() && !lastFileNameUnderCursor.isNull() )
         {
             emit fileIdUnderCursorChanged(fileName);
             model()->updateCell(lastFileNameUnderCursor);
