@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2014 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2018 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,7 +21,6 @@
 // Qt includes
 #include <QApplication>
 #include <QBitmap>
-#include <QDebug>
 #include <QDesktopWidget>
 #include <QMouseEvent>
 #include <QScrollBar>
@@ -344,5 +343,4 @@ void Viewer::InfoBox::updateMapForCurrentImage(DB::FileName)
 }
 #endif
 
-#include "InfoBox.moc"
 // vi:expandtab:tabstop=4 shiftwidth=4:
