@@ -16,8 +16,7 @@
    Boston, MA 02110-1301, USA.
 */
 #include "TaggedArea.h"
-#include <klocale.h>
-#include <QApplication>
+#include <KLocalizedString>
 
 Viewer::TaggedArea::TaggedArea(QWidget *parent) : QFrame(parent)
 {
