@@ -16,8 +16,23 @@
    Boston, MA 02110-1301, USA.
 */
 
+// Local includes
+#include "CompressFileInfo.h"
+#include "Database.h"
+#include "FileReader.h"
+#include "Logging.h"
+#include "XMLCategory.h"
+
+#include <DB/MD5Map.h>
+#include <MainWindow/DirtyIndicator.h>
+#include <MainWindow/Window.h>
+#include <Utilities/Util.h>
+
+// KDE includes
+#include <KLocalizedString>
+#include <KMessageBox>
+
 // Qt includes
-#include <QDebug>
 #include <QFile>
 #include <QHash>
 #include <QLocale>
@@ -25,20 +40,6 @@
 #include <QTextCodec>
 #include <QTextStream>
 
-// KDE includes
-#include <KLocalizedString>
-#include <KMessageBox>
-
-// Local includes
-#include <DB/MD5Map.h>
-#include <MainWindow/DirtyIndicator.h>
-#include <MainWindow/Window.h>
-#include <Utilities/Util.h>
-#include "CompressFileInfo.h"
-#include "Database.h"
-#include "FileReader.h"
-#include "XMLCategory.h"
-
 void XMLDB::FileReader::read( const QString& configFile )
 {
     static QString versionString = QString::fromUtf8("version");
@@ -218,7 +219,7 @@ void XMLDB::FileReader::loadCategories( ReaderPtr reader )
             if ( repairMode )
             {
                 // merge with duplicate category
-                qDebug() << "Repairing category " << categoryName << ": merging items "
+                qCInfo(XMLDBLog) << "Repairing category " << categoryName << ": merging items "
                          << cat->items() << " with " << items;
                 items.append(cat->items());
                 items.removeDuplicates();
@@ -260,7 +261,7 @@ void XMLDB::FileReader::loadImages( ReaderPtr reader )
     while (reader->readNextStartOrStopElement(imageString).isStartToken) {
         const QString fileNameStr = reader->attribute(fileString);
         if ( fileNameStr.isNull() ) {
-            qWarning( "Element did not contain a file attribute" );
+            qCWarning(XMLDBLog, "Element did not contain a file attribute" );
             return;
         }
 
@@ -316,7 +317,7 @@ void XMLDB::FileReader::loadMemberGroups( ReaderPtr reader )
                     DB::CategoryPtr catPtr = m_db->m_categoryCollection.categoryForName( category );
                     if (!catPtr)
                     { // category was not declared in "Categories"
-                        qWarning() << "File corruption in index.xml. Inserting missing category: " << category;
+                        qCWarning(XMLDBLog) << "File corruption in index.xml. Inserting missing category: " << category;
                         catPtr = new XMLCategory(category, QString::fromUtf8("dialog-warning"), DB::Category::TreeView, 32, false);
                         m_db->m_categoryCollection.addCategory( catPtr );
                     }
